Measurements for three penguin species observed in the Palmer Archipelago,
Antarctica.

These data were collected from 2007 - 2009 by Dr. Kristen Gorman with the
[Palmer Station Long Term Ecological Research Program](https://pal.lternet.edu/),
part of the [US Long Term Ecological Research Network](https://lternet.edu/).
The data were originally imported from the
[Environmental Data Initiative](https://environmentaldatainitiative.org/) (EDI)
Data Portal, and are available for use by CC0 license ("No Rights Reserved") in
accordance with the Palmer Station Data Policy. This copy was imported from
[Allison Horst's GitHub repository](https://allisonhorst.github.io/palmerpenguins/articles/intro.html).
